#include <wx/wx.h>
//#include "wx/wxprec.h"
#include <wx/dialog.h>
#include <wx/utils.h>
#include <wx/string.h>
#include <wx/bitmap.h>
#include <wx/timer.h>
#include <wx/dcclient.h>
#include <wx/region.h>
#include "ToasterBoxWindow.h"
#include "ToasterBoxWindowList.h"
#include <wx/listimpl.cpp>

WX_DEFINE_LIST(ToasterBoxWindowList)
